@@ -241,8 +241,12 @@ rgba_t amitk_color_table_lookup(amide_data_t datum, AmitkColorTable which,
     rgba = amitk_color_table_lookup(temp, AMITK_COLOR_TABLE_HOT_METAL, 0, 255);
     break;
   case AMITK_COLOR_TABLE_INV_HOT_METAL_CONTOUR:
-    rgba = amitk_color_table_lookup((max-datum)+min, AMITK_COLOR_TABLE_HOT_METAL_CONTOUR, min, max);
-    rgba.a = 0xFF-rgba.a;
+    temp = 2*(datum-min) * 0xFF/(max-min);
+    if (temp > 255)
+      temp = 511-temp;
+    if (temp < 0)
+      temp = 0;
+    rgba = amitk_color_table_lookup(temp, AMITK_COLOR_TABLE_INV_HOT_METAL, 0, 255);
     break;
   case AMITK_COLOR_TABLE_HOT_BLUE:
     temp_rgba = amitk_color_table_lookup(datum, AMITK_COLOR_TABLE_HOT_METAL, min, max);
