@@ -33,11 +33,11 @@
 #include "amitk_type_builtins.h"
 #include "amitk_data_set.h"
 
-#define GCONF_AMIDE_ROI "ROI/"
-#define GCONF_AMIDE_CANVAS "CANVAS/"
-#define GCONF_AMIDE_MISC "MISC/"
-#define GCONF_AMIDE_DATASETS "DATASETS/"
-#define GCONF_AMIDE_WINDOWS "WINDOWS/"
+#define GCONF_AMIDE_ROI "ROI"
+#define GCONF_AMIDE_CANVAS "CANVAS"
+#define GCONF_AMIDE_MISC "MISC"
+#define GCONF_AMIDE_DATASETS "DATASETS"
+#define GCONF_AMIDE_WINDOWS "WINDOWS"
 
 enum {
   DATA_SET_PREFERENCES_CHANGED,
@@ -52,6 +52,12 @@ static void preferences_finalize            (GObject           *object);
 static GObjectClass * parent_class;
 static guint     preferences_signals[LAST_SIGNAL];
 
+/* external variables */
+const gchar * amitk_which_default_directory_names[] = {
+  N_("None"),
+  N_("Specified Directory"),
+  N_("Working Directory")
+};
 
 
 GType amitk_preferences_get_type(void) {
@@ -122,51 +128,54 @@ static void preferences_init (AmitkPreferences * preferences) {
 
   /* load in saved preferences */
   preferences->canvas_roi_width = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_ROI"Width", AMITK_PREFERENCES_DEFAULT_CANVAS_ROI_WIDTH);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_ROI,"Width", AMITK_PREFERENCES_DEFAULT_CANVAS_ROI_WIDTH);
 
   preferences->canvas_line_style = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_ROI"LineStyle",AMITK_PREFERENCES_DEFAULT_CANVAS_LINE_STYLE);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_ROI,"LineStyle",AMITK_PREFERENCES_DEFAULT_CANVAS_LINE_STYLE);
 
   preferences->canvas_fill_roi = 
-    amide_gconf_get_bool_with_default(GCONF_AMIDE_ROI"FillIsocontour", AMITK_PREFERENCES_DEFAULT_CANVAS_FILL_ROI);
+    amide_gconf_get_bool_with_default(GCONF_AMIDE_ROI,"FillIsocontour", AMITK_PREFERENCES_DEFAULT_CANVAS_FILL_ROI);
 
   preferences->canvas_layout = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS"Layout", AMITK_PREFERENCES_DEFAULT_CANVAS_LAYOUT);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS,"Layout", AMITK_PREFERENCES_DEFAULT_CANVAS_LAYOUT);
 
   preferences->canvas_maintain_size = 
-    amide_gconf_get_bool_with_default(GCONF_AMIDE_CANVAS"MaintainSize", AMITK_PREFERENCES_DEFAULT_CANVAS_MAINTAIN_SIZE);
+    amide_gconf_get_bool_with_default(GCONF_AMIDE_CANVAS,"MaintainSize", AMITK_PREFERENCES_DEFAULT_CANVAS_MAINTAIN_SIZE);
 
   preferences->canvas_target_empty_area = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS"TargetEmptyArea", AMITK_PREFERENCES_DEFAULT_CANVAS_TARGET_EMPTY_AREA);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS,"TargetEmptyArea", AMITK_PREFERENCES_DEFAULT_CANVAS_TARGET_EMPTY_AREA);
 
   preferences->panel_layout = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS"PanelLayout", AMITK_PREFERENCES_DEFAULT_PANEL_LAYOUT);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_CANVAS,"PanelLayout", AMITK_PREFERENCES_DEFAULT_PANEL_LAYOUT);
 
   preferences->warnings_to_console = 
-    amide_gconf_get_bool_with_default(GCONF_AMIDE_MISC"WarningsToConsole", AMITK_PREFERENCES_DEFAULT_WARNINGS_TO_CONSOLE);
+    amide_gconf_get_bool_with_default(GCONF_AMIDE_MISC,"WarningsToConsole", AMITK_PREFERENCES_DEFAULT_WARNINGS_TO_CONSOLE);
 
   preferences->prompt_for_save_on_exit = 
-    amide_gconf_get_bool_with_default(GCONF_AMIDE_MISC"PromptForSaveOnExit", AMITK_PREFERENCES_DEFAULT_PROMPT_FOR_SAVE_ON_EXIT);
+    amide_gconf_get_bool_with_default(GCONF_AMIDE_MISC,"PromptForSaveOnExit", AMITK_PREFERENCES_DEFAULT_PROMPT_FOR_SAVE_ON_EXIT);
+
+  preferences->which_default_directory = 
+    amide_gconf_get_int_with_default(GCONF_AMIDE_MISC,"WhichDefaultDirectory", AMITK_PREFERENCES_DEFAULT_WHICH_DEFAULT_DIRECTORY);
 
   preferences->default_directory = 
-    amide_gconf_get_string_with_default(GCONF_AMIDE_MISC"DefaultDirectory", AMITK_PREFERENCES_DEFAULT_DEFAULT_DIRECTORY);
+    amide_gconf_get_string_with_default(GCONF_AMIDE_MISC,"DefaultDirectory", AMITK_PREFERENCES_DEFAULT_DEFAULT_DIRECTORY);
 
   for (i_modality=0; i_modality<AMITK_MODALITY_NUM; i_modality++) {
-    temp_str = g_strdup_printf(GCONF_AMIDE_DATASETS"DefaultColorTable%s", amitk_modality_get_name(i_modality));
+    temp_str = g_strdup_printf("DefaultColorTable%s", amitk_modality_get_name(i_modality));
     preferences->color_table[i_modality] = 
-      amide_gconf_get_int_with_default(temp_str, amitk_modality_default_color_table[i_modality]);
+      amide_gconf_get_int_with_default(GCONF_AMIDE_DATASETS,temp_str, amitk_modality_default_color_table[i_modality]);
     g_free(temp_str);
   }
 
   for (i_window = 0; i_window < AMITK_WINDOW_NUM; i_window++) 
     for (i_limit = 0; i_limit < AMITK_LIMIT_NUM; i_limit++) {
-      temp_str = g_strdup_printf(GCONF_AMIDE_WINDOWS"%s-%s", amitk_window_get_name(i_window), amitk_limit_get_name(i_limit));
+      temp_str = g_strdup_printf("%s-%s", amitk_window_get_name(i_window), amitk_limit_get_name(i_limit));
       preferences->window[i_window][i_limit] =
-	amide_gconf_get_float_with_default(temp_str, amitk_window_default[i_window][i_limit]);
+	amide_gconf_get_float_with_default(GCONF_AMIDE_WINDOWS,temp_str, amitk_window_default[i_window][i_limit]);
     }
 
   preferences->threshold_style = 
-    amide_gconf_get_int_with_default(GCONF_AMIDE_DATASETS"ThresholdStyle", AMITK_PREFERENCES_DEFAULT_THRESHOLD_STYLE);
+    amide_gconf_get_int_with_default(GCONF_AMIDE_DATASETS,"ThresholdStyle", AMITK_PREFERENCES_DEFAULT_THRESHOLD_STYLE);
 
   preferences->dialog = NULL;
 
@@ -202,7 +211,7 @@ void amitk_preferences_set_canvas_roi_width(AmitkPreferences * preferences,
 
   if (AMITK_PREFERENCES_CANVAS_ROI_WIDTH(preferences) != roi_width) {
     preferences->canvas_roi_width = roi_width;
-    amide_gconf_set_int(GCONF_AMIDE_ROI"Width", roi_width);
+    amide_gconf_set_int(GCONF_AMIDE_ROI,"Width", roi_width);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -216,7 +225,7 @@ void amitk_preferences_set_canvas_line_style(AmitkPreferences * preferences, Gdk
 
   if (AMITK_PREFERENCES_CANVAS_LINE_STYLE(preferences) != line_style) {
     preferences->canvas_line_style = line_style;
-    amide_gconf_set_int(GCONF_AMIDE_ROI"LineStyle",line_style);
+    amide_gconf_set_int(GCONF_AMIDE_ROI,"LineStyle",line_style);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -229,7 +238,7 @@ void amitk_preferences_set_canvas_fill_roi(AmitkPreferences * preferences, gbool
 
   if (AMITK_PREFERENCES_CANVAS_FILL_ROI(preferences) != fill_roi) {
     preferences->canvas_fill_roi = fill_roi;
-    amide_gconf_set_bool(GCONF_AMIDE_ROI"FillIsocontour",fill_roi);
+    amide_gconf_set_bool(GCONF_AMIDE_ROI,"FillIsocontour",fill_roi);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -243,7 +252,7 @@ void amitk_preferences_set_canvas_layout(AmitkPreferences * preferences,
 
   if (AMITK_PREFERENCES_CANVAS_LAYOUT(preferences) != layout) {
     preferences->canvas_layout = layout;
-    amide_gconf_set_int(GCONF_AMIDE_CANVAS"Layout", layout);
+    amide_gconf_set_int(GCONF_AMIDE_CANVAS,"Layout", layout);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -257,7 +266,7 @@ void amitk_preferences_set_canvas_maintain_size(AmitkPreferences * preferences,
 
   if (AMITK_PREFERENCES_CANVAS_MAINTAIN_SIZE(preferences) != maintain_size) {
     preferences->canvas_maintain_size = maintain_size;
-    amide_gconf_set_bool(GCONF_AMIDE_CANVAS"MaintainSize",maintain_size);
+    amide_gconf_set_bool(GCONF_AMIDE_CANVAS,"MaintainSize",maintain_size);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -278,7 +287,7 @@ void amitk_preferences_set_canvas_target_empty_area(AmitkPreferences * preferenc
 
 if (AMITK_PREFERENCES_CANVAS_TARGET_EMPTY_AREA(preferences) != target_empty_area) {
     preferences->canvas_target_empty_area = target_empty_area;
-    amide_gconf_set_bool(GCONF_AMIDE_CANVAS"TargetEmptyArea", target_empty_area);
+    amide_gconf_set_int(GCONF_AMIDE_CANVAS,"TargetEmptyArea", target_empty_area);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -293,7 +302,7 @@ void amitk_preferences_set_panel_layout(AmitkPreferences * preferences,
 
   if (AMITK_PREFERENCES_PANEL_LAYOUT(preferences) != panel_layout) {
     preferences->panel_layout = panel_layout;
-    amide_gconf_set_int(GCONF_AMIDE_CANVAS"PanelLayout", panel_layout);
+    amide_gconf_set_int(GCONF_AMIDE_CANVAS,"PanelLayout", panel_layout);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[STUDY_PREFERENCES_CHANGED], 0);
   }
 
@@ -308,7 +317,7 @@ void amitk_preferences_set_warnings_to_console(AmitkPreferences * preferences, g
 
   if (AMITK_PREFERENCES_WARNINGS_TO_CONSOLE(preferences) != new_value) {
     preferences->warnings_to_console = new_value;
-    amide_gconf_set_bool(GCONF_AMIDE_MISC"WarningsToConsole",new_value);
+    amide_gconf_set_bool(GCONF_AMIDE_MISC,"WarningsToConsole",new_value);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[MISC_PREFERENCES_CHANGED], 0);
   }
   return;
@@ -320,12 +329,26 @@ void amitk_preferences_set_prompt_for_save_on_exit(AmitkPreferences * preference
 
   if (AMITK_PREFERENCES_PROMPT_FOR_SAVE_ON_EXIT(preferences) != new_value) {
     preferences->prompt_for_save_on_exit = new_value;
-    amide_gconf_set_bool(GCONF_AMIDE_MISC"PromptForSaveOnExit",new_value);
+    amide_gconf_set_bool(GCONF_AMIDE_MISC,"PromptForSaveOnExit",new_value);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[MISC_PREFERENCES_CHANGED], 0);
   }
   return;
 }
 
+void amitk_preferences_set_which_default_directory(AmitkPreferences * preferences, AmitkWhichDefaultDirectory new_value) {
+
+  g_return_if_fail(AMITK_IS_PREFERENCES(preferences));
+
+  if (AMITK_PREFERENCES_WHICH_DEFAULT_DIRECTORY(preferences) != new_value) {
+    preferences->which_default_directory = new_value;
+    amide_gconf_set_int(GCONF_AMIDE_MISC,"WhichDefaultDirectory",new_value);
+    g_signal_emit(G_OBJECT(preferences), preferences_signals[MISC_PREFERENCES_CHANGED], 0);
+  }
+  return;
+}
+
+
+
 void amitk_preferences_set_default_directory(AmitkPreferences * preferences, const gchar * new_directory) {
 
   gboolean different=FALSE;
@@ -343,7 +366,7 @@ void amitk_preferences_set_default_directory(AmitkPreferences * preferences, con
       g_free(preferences->default_directory);
     if (new_directory != NULL)
       preferences->default_directory = g_strdup(new_directory);
-    amide_gconf_set_string(GCONF_AMIDE_MISC"DefaultDirectory", new_directory);
+    amide_gconf_set_string(GCONF_AMIDE_MISC,"DefaultDirectory", new_directory);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[MISC_PREFERENCES_CHANGED], 0);
   }
   return;
@@ -361,9 +384,9 @@ void amitk_preferences_set_color_table(AmitkPreferences * preferences,
   if (AMITK_PREFERENCES_COLOR_TABLE(preferences,modality) != color_table) {
     preferences->color_table[modality] = color_table;
 
-    temp_string = g_strdup_printf(GCONF_AMIDE_DATASETS"DefaultColorTable%s", 
+    temp_string = g_strdup_printf("DefaultColorTable%s", 
 				  amitk_modality_get_name(modality));
-    amide_gconf_set_int(temp_string, color_table);
+    amide_gconf_set_int(GCONF_AMIDE_DATASETS,temp_string, color_table);
     g_free(temp_string);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[DATA_SET_PREFERENCES_CHANGED], 0);
   }
@@ -385,9 +408,9 @@ void amitk_preferences_set_default_window(AmitkPreferences * preferences,
   if (!REAL_EQUAL(AMITK_PREFERENCES_WINDOW(preferences, window, limit), value)) {
     preferences->window[window][limit] = value;
 
-    temp_string = g_strdup_printf(GCONF_AMIDE_WINDOWS"%s-%s", amitk_window_get_name(window),
+    temp_string = g_strdup_printf("%s-%s", amitk_window_get_name(window),
 				  amitk_limit_get_name(limit));
-    amide_gconf_set_float(temp_string,value);
+    amide_gconf_set_float(GCONF_AMIDE_WINDOWS,temp_string,value);
     g_free(temp_string);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[DATA_SET_PREFERENCES_CHANGED], 0);
   }
@@ -402,7 +425,7 @@ void amitk_preferences_set_threshold_style(AmitkPreferences * preferences,
 
   if (AMITK_PREFERENCES_THRESHOLD_STYLE(preferences) != threshold_style) {
     preferences->threshold_style = threshold_style;
-    amide_gconf_set_int(GCONF_AMIDE_DATASETS"ThresholdStyle", threshold_style);
+    amide_gconf_set_int(GCONF_AMIDE_DATASETS,"ThresholdStyle", threshold_style);
     g_signal_emit(G_OBJECT(preferences), preferences_signals[DATA_SET_PREFERENCES_CHANGED], 0);
   }
 }
@@ -414,3 +437,30 @@ void amitk_preferences_set_dialog(AmitkPreferences * preferences,
   preferences->dialog = dialog;
 
 }
+
+/* conviencence function */
+void amitk_preferences_set_file_chooser_directory(AmitkPreferences * preferences,
+						  GtkWidget * file_chooser) {
+
+  g_return_if_fail(AMITK_IS_PREFERENCES(preferences));
+  g_return_if_fail(GTK_IS_FILE_CHOOSER(file_chooser));
+
+  switch(AMITK_PREFERENCES_WHICH_DEFAULT_DIRECTORY(preferences)) {
+
+  case AMITK_WHICH_DEFAULT_DIRECTORY_SPECIFIED:
+    if (AMITK_PREFERENCES_DEFAULT_DIRECTORY(preferences) != NULL)
+      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), 
+					  AMITK_PREFERENCES_DEFAULT_DIRECTORY(preferences));
+    break;
+
+  case AMITK_WHICH_DEFAULT_DIRECTORY_WORKING:
+    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), "");
+    break;
+
+  case AMITK_WHICH_DEFAULT_DIRECTORY_NONE:
+  default:
+    break;
+  }
+}
+
+
