@@ -780,7 +780,7 @@ void amitk_roi_erase_volume(const AmitkRoi * roi,
       amitk_roi_calculate_on_data_set(roi, ds, i_frame, i_gate, outside, FALSE, erase_volume, ds);
 
   /* recalc max and min */
-  amitk_data_set_calc_max_min(ds, update_func, update_data);
+  amitk_data_set_calc_min_max(ds, update_func, update_data);
 
   /* mark the distribution data as invalid */
   if (AMITK_DATA_SET_DISTRIBUTION(ds) != NULL) {
