@@ -27,17 +27,5 @@
 /* includes always needed with this */
 #include "amitk_study.h"
 
-
-#ifdef AMIDE_LIBGSL_SUPPORT
-
 /* external functions */
 void tb_alignment(AmitkStudy * study, GtkWindow * parent);
-
-#endif
-
-
-
-
-
-
-
